/*****************************************************
 * DFplayer　制御プログラム　
 * 使用マイコン　PIC16F1938
 * 2020/08/21
 * コインセレクターで動作するように変更。
******************************************************/
#include <xc.h>
#include <stdio.h>
#include "command.h"

/*****コンフィグレーション設定*********/
// コンフィギュレーション１の設定
#pragma config FOSC = INTOSC    // 内部ｸﾛｯｸを使用する(INTOSC)
#pragma config WDTE = OFF       // ｳｵｯﾁﾄﾞｯｸﾞﾀｲﾏｰ無し(OFF)
#pragma config PWRTE = ON       // 電源ONから64ms後にﾌﾟﾛｸﾞﾗﾑを開始する(ON)
#pragma config MCLRE = ON      // 外部ﾘｾｯﾄ信号を使用
#pragma config CP = OFF         // ﾌﾟﾛｸﾞﾗﾑﾒﾓﾘｰを保護しない(OFF)
#pragma config CPD = OFF        // ﾃﾞｰﾀﾒﾓﾘｰを保護しない(OFF)
#pragma config BOREN = ON       // 電源電圧降下常時監視機能ON(ON)
#pragma config CLKOUTEN = OFF   // CLKOUTﾋﾟﾝをRA6ﾋﾟﾝで使用する(OFF)
#pragma config IESO = OFF       // 外部・内部ｸﾛｯｸの切替えでの起動はなし(OFF)
#pragma config FCMEN = OFF      // 外部ｸﾛｯｸ監視しない(FCMEN_OFF)

// コンフィギュレーション２の設定
#pragma config WRT = OFF        // Flashﾒﾓﾘｰを保護しない(OFF)
#pragma config PLLEN = OFF      // 動作クロックを32MHzでは動作させない(OFF)
#pragma config STVREN = ON      // スタックがオーバフローやアンダーフローしたらリセットをする(ON)
#pragma config BORV = HI        // 電源電圧降下常時監視電圧(2.5V)設定(HI)
#pragma config LVP = OFF        // 低電圧プログラミング機能使用しない(OFF)

/* 内部クロック　８ＭＨｚ */
#define  _XTAL_FREQ     8000000		//ディレイ用

unsigned	int coin_in;              //
/********　サブ関数　************/
void putch(unsigned char byte);

/********　メイン開始　************/
void main(void) {

/********　変数定義　************/
	/*******初期設定***** */
    OSCCON = 0x72;				//内臓クロック８HMz指定(BPLL Off
    ANSELA = 0x00;				//A/D停止
    ANSELB = 0x00;				//A/D停止

    TRISA  = 0b00000000;		//ポートＡすべて出力
    TRISB  = 0b00000001;		//RB6 RB7出力　他入力
    TRISC  = 0b10000000;		//

    /* USART初期設定*/
    TXSTA = 0x24;				//シリアル送信設定
    RCSTA = 0x90;				//シリアル受信設定
	BAUDCON=0x08;				//
	SPBRG = 207;				//ボーレート  SPBRG=103時19.2kbps
								//             SPBRG=207時9600bps
/****************************************************
 *  外部割り込み設定　
 * RB0　ポート　High→Low時割り込み発生 
 * 
****************************************************/
	INTF = 0;					//外部割り込みフラグクリア
	INTE = 1;					//外部割り込み許可
	INTEDG = 0;					//立下り（LOW）時割り込み
//	IOCIE = 0;					//状態割り込み無効
   	PEIE = 1;					//周辺割り込み許可
	GIE = 1;					//全体割り込み許可 
/************　PICが動作しているか確認用　********************/	
//	printf("\r\nHELLO Ver1.1 \r\n");	//\r　復帰　\n　改行
	PORTA = 0xFF;						//ポートAに接続しているLEDをOFF
    __delay_ms(500);
//使用デバイスの指定
        device_set(); 
        __delay_ms(300);

//  音量調整       
        com_Volume(0x0f); 
        __delay_ms(300);        //300ms ウエイト 
	while (1) {
        
        if(coin_in){            //コインが投入されたか？
           coin_in = 0; 

//  トラック１を再生する。
        com_playtrk(01);    
		__delay_ms(10000);       
 
 //  次のトラックを再生する。 
        com_fwdplay();	
        __delay_ms(6000);   
        
 //  次のトラックを再生する。 
        com_fwdplay();	
        __delay_ms(3000);
		}
    }   
}

 /************************************************************
 * printf用
 ***********************************************************/
void putch(unsigned char byte){
		RCSTAbits.SPEN=1;
		TXREG=byte;
		while(!TXIF)continue;
		TXIF=0;
}
 /************************************************************
  割り込み　処理関数
  外部割り込み　RB0がLOWになった時割り込み
 ***********************************************************/
void interrupt isr(void)
{
    //外部割り込み処理　RB0がLOW(コイン投入）になった時割り込み発生
	INTF = 0;						//フラグクリアー

    coin_in = 1;
			
}